# pylint: disable=redefined-outer-name,unused-variable,expression-not-assigned,singleton-comparison

import pytest

import log

from . import demo, other


def describe_text():

    def it_includes_the_caller_location(expect, caplog):
        demo.greet("caller")
        expect(caplog.text) == \
            "demo.py                      5 ERROR    Hello, caller!\n"

    @pytest.mark.last
    def it_can_be_formatted_with_init(expect, caplog):
        log.init(format=log.helpers.DEFAULT_FORMAT, level=log.WARNING)
        demo.greet("format")
        expect(caplog.text) == "ERROR: tests.demo: Hello, format!\n"

    def it_can_include_exceptions(expect, caplog):
        try:
            print(1 / 0)
        except ZeroDivisionError:
            log.exception("exception")
        expect(caplog.text).contains('Traceback ')
        expect(caplog.text).contains('test_records.py", line 25, ')
        expect(caplog.text).contains('ZeroDivisionError')


def describe_silence():

    def when_off(expect, caplog):
        log.silence('3rd-party')
        other.do_3rd_party_thing()
        expect(caplog.records) == []

    def with_errors(expect, caplog):
        log.silence('3rd-party', allow_error=True)
        other.do_3rd_party_thing()
        expect(len(caplog.records)) == 1

    def with_warnings(expect, caplog):
        log.silence('3rd-party', allow_warning=True)
        other.do_3rd_party_thing()
        expect(len(caplog.records)) == 2

    def with_infos(expect, caplog):
        log.silence('3rd-party', allow_info=True)
        other.do_3rd_party_thing()
        expect(len(caplog.records)) == 3



#!/usr/bin/env python

"""Setup script for the package."""

import os
import sys

import setuptools


PACKAGE_NAME = 'log'


def read_package_variable(key, filename='__init__.py'):
    """Read the value of a variable from the package without importing."""
    module_path = os.path.join(PACKAGE_NAME, filename)
    with open(module_path) as module:
        for line in module:
            parts = line.strip().split(' ', 2)
            if parts[:-1] == [key, '=']:
                return parts[-1].strip("'")
    sys.exit("'%s' not found in '%s'", key, module_path)


def build_description():
    """Build a description for the project from documentation files."""
    readme = open("README.md").read()
    changelog = open("CHANGELOG.md").read()
    return readme + '\n' + changelog


setuptools.setup(
    name=read_package_variable('__project__'),
    version=read_package_variable('__version__'),

    description="Minimalistic wrapper for Python logging.",
    url='https://github.com/jacebrowning/minilog',
    author='Jace Browning',
    author_email='jacebrowning@gmail.com',

    packages=setuptools.find_packages(),

    long_description=build_description(),
    long_description_content_type='text/markdown',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python',
        'Topic :: Software Development',
        'Topic :: System :: Logging',
    ],
)
